@@ -7,8 +7,7 @@ archive_dependencies_check() {
 	assert_not_empty 'archive' 'archive_dependencies_check'
 
 	# Check extraction dependencies for main archive.
-	## When this function is called inside `{ … } || true`, errexit does not stop execution on errors. This is the expected errexit behaviour for commands called in the left hand operand of an || operator.
-	archive_dependencies_check_single "$archive" || return 1
+	archive_dependencies_check_single "$archive"
 
 	# Check extraction dependencies for archive extra parts.
 	local archive_part
@@ -32,11 +31,9 @@ archive_dependencies_check_single() {
 	local archive_extractor
 	archive_extractor=$(archive_extractor "$archive")
 	if [ -n "$archive_extractor" ]; then
-		## When this function is called inside `{ … } || true`, errexit does not stop execution on errors. This is the expected errexit behaviour for commands called in the left hand operand of an || operator.
-		archive_dependencies_check_using_extractor "$archive" || return 1
+		archive_dependencies_check_using_extractor "$archive"
 	else
-		## When this function is called inside `{ … } || true`, errexit does not stop execution on errors. This is the expected errexit behaviour for commands called in the left hand operand of an || operator.
-		archive_dependencies_check_from_type "$archive" || return 1
+		archive_dependencies_check_from_type "$archive"
 	fi
 }
 
@@ -97,6 +94,9 @@ archive_dependencies_check_from_type() {
 		('7z')
 			archive_dependencies_check_type_7z
 		;;
+		('appimage')
+			archive_dependencies_check_type_appimage
+		;;
 		('cabinet')
 			archive_dependencies_check_type_cabinet
 		;;
@@ -156,6 +156,11 @@ archive_dependencies_check_from_type() {
 archive_extraction_default() {
 	local archive
 	archive=$(current_archive)
+	if [ -z "$archive" ]; then
+		error_archive_extraction_default_missing_archive
+		return 1
+	fi
+
 	archive_extraction "$archive"
 
 	# Extract the contents from the extra archives providing required libraries
@@ -272,6 +277,9 @@ archive_extraction_from_type() {
 		('7z')
 			archive_extraction_7z "$archive" "$destination_directory" "$log_file"
 		;;
+		('appimage')
+			archive_extraction_appimage "$archive" "$destination_directory" "$log_file"
+		;;
 		('cabinet')
 			archive_extraction_cabinet "$archive" "$destination_directory" "$log_file"
 		;;
