@@ -144,7 +144,7 @@ launcher_write_script() {
 	chmod 755 "$launcher_path"
 
 	## The *_launcher functions are called on their own first, to avoid being spawned in a subshell. This prevents their return code from being lost.
-	## The package context is always set to ensure context-sensitive values for runtime options are used.
+	## The package context is always set to ensure context-sensitive values for runtime options (and for the path to game data) are used.
 	local application_type launcher_content
 	application_type=$(
 		set_current_package "$package"
@@ -228,6 +228,7 @@ launcher_write_script() {
 			winetricks_verbs=$(wine_winetricks_verbs)
 			if [ -n "$winetricks_verbs" ]; then
 				dependencies_add_command "$package" 'winetricks'
+				dependencies_add_command "$package" 'terminal_wrapper'
 			fi
 			## Add package dependencies on winetricks and rendering libraries if a non-default Direct3D renderer is required.
 			local direct3d_renderer
@@ -235,6 +236,7 @@ launcher_write_script() {
 			case "$direct3d_renderer" in
 				('wined3d/'*)
 					dependencies_add_command "$package" 'winetricks'
+					dependencies_add_command "$package" 'terminal_wrapper'
 					local wined3d_backend
 					wined3d_backend=$(printf '%s' "$direct3d_renderer" | cut --delimiter='/' --fields=2)
 					case "$wined3d_backend" in
@@ -247,11 +249,23 @@ launcher_write_script() {
 					esac
 				;;
 				('dxvk')
-					dependencies_add_command "$package" 'winetricks'
+					local option_package
+					option_package=$(option_value 'package')
+					case "$option_package" in
+						('deb')
+							dependencies_add_command "$package" 'dxvk-setup | winetricks'
+							dependencies_add_command "$package" 'terminal_wrapper'
+						;;
+						(*)
+							dependencies_add_command "$package" 'winetricks'
+							dependencies_add_command "$package" 'terminal_wrapper'
+						;;
+					esac
 					dependencies_add_native_libraries "$package" 'libvulkan.so.1'
 				;;
 				('vkd3d')
 					dependencies_add_command "$package" 'winetricks'
+					dependencies_add_command "$package" 'terminal_wrapper'
 					dependencies_add_native_libraries "$package" 'libvulkan.so.1'
 				;;
 			esac
